require 'win32ole'

output = "output.ppt"   # 出力ファイル名
title = "Sample"        # タイトル
imgpath = "./ggraph_hop_irb01.png"   # 挿入する画像のパス (相対パス可)
text = "text"           # 挿入するテキスト
fontsize = 30           # 挿入するテキストのフォントサイズ

# 絶対パスの取得
def getAbsolutePath(path)
  fso = WIN32OLE.new('Scripting.FileSystemObject')
  return fso.GetAbsolutePathname(path)
end

# PowerPoint アプリケーションを開く
pp =  WIN32OLE.new('PowerPoint.Application')

# 事故防止のため, 既にファイルを開いている場合は処理をしない
if pp.Presentations.Count > 0 then
  puts "ERROR: Close all PowerPoint file and rerun this script."
  exit 1
end

# アプリケーションウィンドウを表示
pp.Visible = true

# スライドファイルの新規作成
presen = pp.Presentations.add

# スライドのサイズを取得
p slidewidth  = presen.pageSetup.slideWidth
p slideheight = presen.pageSetup.slideHeight

# 現在の総ページ数を取得
p ipage = presen.Slides.Count

# 新しいページを末尾ページの次に作成
newSlide = presen.Slides.Add(ipage + 1, 11)
slideShape = newSlide.Shapes

# タイトルの変更
slideShape.Title.TextFrame.TextRange.Text = title

# 画像の挿入, 設定
imgpath = getAbsolutePath(imgpath)
bodyShape = slideShape.AddPicture(imgpath, false, true, 10, 10 )
bodyShape.LockAspectRatio = true    # 縦横比を固定
bodyShape.width  = 320    # 画像の幅をリサイズ
bodyShape.left = 200       # スライド左端からの位置を指定
bodyShape.top =  150       # スライド上端からの位置を指定

# テキストボックスの挿入, 設定
left = bodyShape.left
top = bodyShape.top - 1.5 * fontsize   # 図より少し上に設置
width = bodyShape.width
height = fontsize
orientation = 1   # テキストの方向. 1 は横書き, 2 は縦書き(下から上), 3 は縦書き (上から下)
tb = slideShape.addTextBox(orientation, left, top, width, height)   # 空の textbox 作成
tr = tb.textFrame.textRange
tr.text = text                    # テキストボックスにテキストを挿入
tr.font.size = fontsize           # フォントサイズの設定
tr.ParagraphFormat.Alignment = 2  # 1: 左揃え, 2: 中央揃え

# ファイルへ出力. 既にファイルがある場合は出力されない
if output then
  output = getAbsolutePath(output)
  unless File.exist?(output)
    presen.SaveAs(output)
  else
    puts "ERROR: file exists."
  end
end

#pp.Quit   # PowerPoint アプリケーションの終了
